@@ -295,7 +295,7 @@ load_changed_cb (WebKitWebView *web_view,
   if (load_event == WEBKIT_LOAD_COMMITTED) {
     ephy_embed_destroy_top_widgets (embed);
     address = ephy_web_view_get_address (EPHY_WEB_VIEW (web_view));
-    ephy_embed_set_overview_mode (embed, strcmp (address, "about:overview") == 0);
+    ephy_embed_set_overview_mode (embed, strcmp (address, "ephy-about:overview") == 0);
   }
 }
 #else
@@ -310,7 +310,7 @@ load_status_changed_cb (WebKitWebView *web_view,
   if (status == WEBKIT_LOAD_COMMITTED) {
     ephy_embed_destroy_top_widgets (embed);
     address = ephy_web_view_get_address (EPHY_WEB_VIEW (web_view));
-    ephy_embed_set_overview_mode (embed, strcmp (address, "about:overview") == 0);
+    ephy_embed_set_overview_mode (embed, strcmp (address, "ephy-about:overview") == 0);
   }
 }
 #endif
@@ -635,7 +635,7 @@ ephy_embed_auto_download_url (EphyEmbed *embed, const char *url)
 {
   EphyDownload *download;
 
-  download = ephy_download_new_for_uri (url);
+  download = ephy_download_new_for_uri (url, NULL);
   ephy_download_set_auto_destination (download);
   ephy_download_set_action (download, EPHY_DOWNLOAD_ACTION_OPEN);
 }
@@ -647,17 +647,19 @@ download_requested_cb (WebKitWebView *web_view,
                        EphyEmbed *embed)
 {
   EphyDownload *ed;
-  GtkWidget *window;
+  GtkWidget *toplevel;
+  GtkWindow *window = NULL;
 
   /* Is download locked down? */
   if (g_settings_get_boolean (EPHY_SETTINGS_LOCKDOWN,
                               EPHY_PREFS_LOCKDOWN_SAVE_TO_DISK))
     return FALSE;
 
-  window = gtk_widget_get_toplevel (GTK_WIDGET (embed));
+  toplevel = gtk_widget_get_toplevel (GTK_WIDGET (embed));
+  if (GTK_IS_WINDOW (toplevel))
+    window = GTK_WINDOW (toplevel);
 
-  ed = ephy_download_new_for_download (download);
-  ephy_download_set_window (ed, window);
+  ed = ephy_download_new_for_download (download, window);
   ephy_download_set_auto_destination (ed);
 
   return TRUE;
@@ -734,7 +736,9 @@ status_message_notify_cb (EphyWebView *view, GParamSpec *pspec, EphyEmbed *embed
   } else {
     /* A short timeout before hiding the statusbar ensures that while moving
       over a series of links, the overlay widget doesn't flicker on and off. */
-    priv->pop_statusbar_later_source_id = g_timeout_add (250, pop_statusbar_later_cb, embed);
+    if (priv->pop_statusbar_later_source_id == 0) {
+      priv->pop_statusbar_later_source_id = g_timeout_add (250, pop_statusbar_later_cb, embed);
+    }
   }
 }
 
@@ -815,7 +819,8 @@ progress_update (EphyWebView *view, GParamSpec *pspec, EphyEmbed *embed)
   }
 
   uri = webkit_web_view_get_uri (priv->web_view);
-  if (!uri || g_str_equal (uri, "about:blank"))
+  if (!uri || g_str_has_prefix (uri, "ephy-about:") ||
+      g_str_has_prefix (uri, "about:"))
     return;
 
 #ifdef HAVE_WEBKIT2
@@ -890,6 +895,16 @@ ephy_embed_constructed (GObject *object)
   gtk_container_add (GTK_CONTAINER (overlay), scrolled_window);
 #endif
 
+  /* The overview */
+  priv->overview = ephy_overview_new ();
+  gtk_widget_set_halign (priv->overview, GTK_ALIGN_FILL);
+  gtk_widget_set_valign (priv->overview, GTK_ALIGN_FILL);
+  gtk_overlay_add_overlay (GTK_OVERLAY (overlay), priv->overview);
+
+  g_object_bind_property (embed, "overview-mode",
+                          priv->overview, "visible",
+                          G_BINDING_SYNC_CREATE);
+
   /* Floating message popup for fullscreen mode. */
   priv->fullscreen_message_label = gtk_label_new (NULL);
   gtk_widget_set_name (priv->fullscreen_message_label, "fullscreen-popup");
@@ -1021,22 +1036,6 @@ ephy_embed_constructed (GObject *object)
                     NULL);
 #endif
 
-  /* The overview */
-  priv->overview = ephy_overview_new ();
-  gtk_box_pack_start (GTK_BOX (embed),
-                      GTK_WIDGET (priv->overview),
-                      TRUE, TRUE, 0);
-  g_object_bind_property (embed, "overview-mode",
-                          priv->overview, "visible",
-                          G_BINDING_SYNC_CREATE
-                          | G_BINDING_BIDIRECTIONAL);
-
-  g_object_bind_property (embed, "overview-mode",
-                          paned, "visible",
-                          G_BINDING_SYNC_CREATE
-                          | G_BINDING_INVERT_BOOLEAN
-                          | G_BINDING_BIDIRECTIONAL);
-
   ephy_embed_prefs_add_embed (embed);
 }
 
