@@ -33,11 +33,10 @@
 #include "ephy-node-common.h"
 #include "ephy-node-view.h"
 #include "ephy-prefs.h"
-#include "ephy-search-entry.h"
 #include "ephy-session.h"
 #include "ephy-settings.h"
 #include "ephy-shell.h"
-#include "ephy-state.h"
+#include "ephy-initial-state.h"
 #include "ephy-topic-action.h"
 #include "ephy-window.h"
 #include "popup-commands.h"
@@ -291,7 +290,7 @@ get_target_window (EphyBookmarksEditor *editor)
 	}
 	else
 	{
-                return GTK_WIDGET (ephy_shell_get_active_window (ephy_shell));
+		return GTK_WIDGET (gtk_application_get_active_window (GTK_APPLICATION (ephy_shell_get_default ())));
 	}
 }
 
@@ -315,7 +314,8 @@ cmd_open_bookmarks_in_tabs (GtkAction *action,
 		location = ephy_node_get_property_string (node,
 						EPHY_NODE_BMK_PROP_LOCATION);
 
-		new_embed = ephy_shell_new_tab (ephy_shell, window, NULL, location,
+		new_embed = ephy_shell_new_tab (ephy_shell_get_default (),
+						window, NULL, location,
 				 	        EPHY_NEW_TAB_OPEN_PAGE |
 					        EPHY_NEW_TAB_IN_EXISTING_WINDOW);
 		/* if there was no target window, a new one was opened. Get it
@@ -351,8 +351,10 @@ cmd_open_bookmarks_in_browser (GtkAction *action,
 		location = ephy_node_get_property_string (node,
 						EPHY_NODE_BMK_PROP_LOCATION);
 
-		ephy_shell_new_tab (ephy_shell, window, NULL, location,
-				    EPHY_NEW_TAB_OPEN_PAGE | EPHY_NEW_TAB_IN_NEW_WINDOW);
+		ephy_shell_new_tab (ephy_shell_get_default (),
+				    window, NULL, location,
+				    EPHY_NEW_TAB_OPEN_PAGE |
+				    EPHY_NEW_TAB_IN_NEW_WINDOW);
 	}
 
 	g_list_free (selection);
@@ -1044,7 +1046,8 @@ ephy_bookmarks_editor_node_activated_cb (GtkWidget *view,
 		(node, EPHY_NODE_BMK_PROP_LOCATION);
 	g_return_if_fail (location != NULL);
 
-	ephy_shell_new_tab (ephy_shell, NULL, NULL, location,
+	ephy_shell_new_tab (ephy_shell_get_default (),
+			    NULL, NULL, location,
 			    EPHY_NEW_TAB_OPEN_PAGE);
 }
 
@@ -1062,7 +1065,8 @@ ephy_bookmarks_editor_node_middle_clicked_cb (GtkWidget *view,
 		(node, EPHY_NODE_BMK_PROP_LOCATION);
 	g_return_if_fail (location != NULL);
 
-	ephy_shell_new_tab (ephy_shell, window, NULL, location,
+	ephy_shell_new_tab (ephy_shell_get_default (),
+			    window, NULL, location,
 			    EPHY_NEW_TAB_OPEN_PAGE |
 			    EPHY_NEW_TAB_IN_EXISTING_WINDOW);
 }
@@ -1323,7 +1327,7 @@ keyword_node_selected_cb (EphyNodeView *view,
 	}
 	else
 	{
-		ephy_search_entry_clear (EPHY_SEARCH_ENTRY (editor->priv->search_entry));
+		gtk_entry_set_text (GTK_ENTRY (editor->priv->search_entry), "");
 		bookmarks_filter (editor, node);
 	}
 }
@@ -1341,9 +1345,10 @@ keyword_node_show_popup_cb (GtkWidget *view, EphyBookmarksEditor *editor)
 }
 
 static void
-search_entry_search_cb (GtkWidget *entry, const char *search_text, EphyBookmarksEditor *editor)
+search_entry_changed_cb (GtkWidget *entry, EphyBookmarksEditor *editor)
 {
 	EphyNode *all;
+	const char *search_text;
 
 	g_signal_handlers_block_by_func
 		(G_OBJECT (editor->priv->key_view),
@@ -1357,6 +1362,8 @@ search_entry_search_cb (GtkWidget *entry, const char *search_text, EphyBookmarks
 		 G_CALLBACK (keyword_node_selected_cb),
 		 editor);
 
+	search_text = gtk_entry_get_text (GTK_ENTRY (entry));
+
 	ephy_node_filter_empty (editor->priv->bookmarks_filter);
 	ephy_node_filter_add_expression (editor->priv->bookmarks_filter,
 					 ephy_node_filter_expression_new (EPHY_NODE_FILTER_EXPRESSION_STRING_PROP_CONTAINS,
@@ -1380,35 +1387,23 @@ static GtkWidget *
 build_search_box (EphyBookmarksEditor *editor)
 {
 	GtkWidget *box;
-	GtkWidget *label;
 	GtkWidget *entry;
-	char *str;
 
 	box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
 	gtk_container_set_border_width (GTK_CONTAINER (box), 6);
 	gtk_widget_show (box);
 
-	entry = ephy_search_entry_new ();
+	entry = gtk_search_entry_new ();
 	editor->priv->search_entry = entry;
 	
-	g_signal_connect (G_OBJECT (entry), "search",
-			  G_CALLBACK (search_entry_search_cb),
+	g_signal_connect (G_OBJECT (entry), "changed",
+			  G_CALLBACK (search_entry_changed_cb),
 			  editor);
 	add_entry_monitor (editor, entry);
 	add_focus_monitor (editor, entry);
 	
 	gtk_widget_show_all (entry);
 
-	label = gtk_label_new (NULL);
-	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	str = g_strconcat ("<b>", _("_Search:"), "</b>", NULL);
-	gtk_label_set_markup_with_mnemonic (GTK_LABEL (label), str);
-	g_free (str);
-	gtk_label_set_mnemonic_widget (GTK_LABEL (label), entry);
-	gtk_widget_show (label);
-
-	gtk_box_pack_start (GTK_BOX (box),
-			    label, FALSE, TRUE, 0);
 	gtk_box_pack_start (GTK_BOX (box),
 			    entry, TRUE, TRUE, 0);
 
@@ -1769,13 +1764,13 @@ ephy_bookmarks_editor_construct (EphyBookmarksEditor *editor)
 			  G_CALLBACK (view_selection_changed_cb),
 			  editor);
 
-	ephy_state_add_window (GTK_WIDGET(editor),
-			       "bookmarks_editor",
-			       450, 400, FALSE,
-			       EPHY_STATE_WINDOW_SAVE_SIZE | EPHY_STATE_WINDOW_SAVE_POSITION);
-	ephy_state_add_paned  (GTK_WIDGET (hpaned),
-			       "bookmarks_paned",
-			       130);
+	ephy_initial_state_add_window (GTK_WIDGET(editor),
+                                       "bookmarks_editor",
+                                       450, 400, FALSE,
+                                       EPHY_INITIAL_STATE_WINDOW_SAVE_SIZE | EPHY_INITIAL_STATE_WINDOW_SAVE_POSITION);
+	ephy_initial_state_add_paned  (GTK_WIDGET (hpaned),
+                                       "bookmarks_paned",
+                                       130);
 
 	/* Lockdown settings */
 	action = gtk_action_group_get_action (action_group, "Export");
