@@ -113,7 +113,7 @@ ephy_shell_startup_context_new (EphyStartupFlags startup_flags,
 }
 
 static void
-queue_commands (EphyShell *shell)
+ephy_shell_startup_continue (EphyShell *shell)
 {
   EphyShellStartupContext *ctx;
   EphySession *session;
@@ -123,36 +123,14 @@ queue_commands (EphyShell *shell)
 
   ctx = shell->priv->startup_context;
 
-  /* We only get here when starting a new instance, so autoresume the
-   * session unless we are in application mode. */
-  if (ephy_embed_shell_get_mode (EPHY_EMBED_SHELL (shell)) != EPHY_EMBED_SHELL_MODE_APPLICATION)
-    ephy_session_queue_command (session,
-                                EPHY_SESSION_CMD_RESUME_SESSION,
-                                NULL, NULL, ctx->user_time, TRUE);
-
   if (ctx->session_filename != NULL)
-    ephy_session_queue_command (session,
-                                EPHY_SESSION_CMD_LOAD_SESSION,
-                                (const char *)ctx->session_filename, NULL,
-                                ctx->user_time, FALSE);
+    ephy_session_load (session, (const char *)ctx->session_filename,
+                       ctx->user_time, NULL, NULL, NULL);
   else if (ctx->arguments != NULL) {
     /* Don't queue any window openings if no extra arguments given, */
     /* since session autoresume will open one for us. */
-    GString *options;
-
-    options = g_string_sized_new (64);
-
-    if (ctx->startup_flags & EPHY_STARTUP_NEW_WINDOW)
-      g_string_append (options, "new-window,");
-
-    if (ctx->startup_flags & EPHY_STARTUP_NEW_TAB)
-      g_string_append (options, "new-tab,external,");
-
-    ephy_session_queue_command (session,
-                                EPHY_SESSION_CMD_OPEN_URIS,
-                                (const char*)options->str,
-                                (const char **)ctx->arguments,
-                                ctx->user_time, FALSE);
+    ephy_session_open_uris (session, (const char **)ctx->arguments,
+                            ctx->startup_flags, ctx->user_time);
   }
 }
 
@@ -262,14 +240,36 @@ ephy_shell_startup (GApplication* application)
   }
 }
 
+static void
+session_load_cb (GObject *object,
+                 GAsyncResult *result,
+                 gpointer user_data)
+{
+  EphySession *session = EPHY_SESSION (object);
+  EphyShell *shell = EPHY_SHELL (user_data);
+
+  ephy_session_resume_finish (session, result, NULL);
+  ephy_shell_startup_continue (shell);
+}
+
 static void
 ephy_shell_activate (GApplication *application)
 {
+  EphyShell *shell = EPHY_SHELL (application);
+
   /*
-   * We get here on each new instance (remote or not). Queue the
+   * We get here on each new instance (remote or not). Autoresume the
+   * session unless we are in application mode and queue the
    * commands.
    */
-  queue_commands (EPHY_SHELL (application));
+  if (ephy_embed_shell_get_mode (EPHY_EMBED_SHELL (shell)) != EPHY_EMBED_SHELL_MODE_APPLICATION) {
+    EphyShellStartupContext *ctx;
+
+    ctx = shell->priv->startup_context;
+    ephy_session_resume (EPHY_SESSION (ephy_shell_get_session (shell)),
+                         ctx->user_time, NULL, session_load_cb, shell);
+  } else
+    ephy_shell_startup_continue (shell);
 }
 
 /*
@@ -595,8 +595,9 @@ download_started_cb (WebKitWebContext *web_context,
                      WebKitDownload *download,
                      EphyShell *shell)
 {
-  EphyDownload *ed;
-  EphyWindow *window;
+  GtkWindow *window = NULL;
+  WebKitWebView *web_view;
+  gboolean ephy_download_set;
 
   /* Is download locked down? */
   if (g_settings_get_boolean (EPHY_SETTINGS_LOCKDOWN,
@@ -605,10 +606,28 @@ download_started_cb (WebKitWebContext *web_context,
     return;
   }
 
-  window = gtk_application_get_active_window (GTK_APPLICATION (shell));
+  /* Only create an EphyDownload for the WebKitDownload if it doesn't exist yet.
+   * This can happen when the download has been started automatically by WebKit,
+   * due to a context menu action or policy checker decision. Downloads started
+   * explicitly by Epiphany are marked with ephy-download-set GObject data.
+   */
+  ephy_download_set = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (download), "ephy-download-set"));
+  if (ephy_download_set)
+    return;
 
-  ed = ephy_download_new_for_download (download);
-  ephy_download_set_window (ed, GTK_WIDGET (window));
+  web_view = webkit_download_get_web_view (download);
+  if (web_view) {
+    GtkWidget *toplevel;
+
+    toplevel = gtk_widget_get_toplevel (GTK_WIDGET (web_view));
+    if (GTK_IS_WINDOW (toplevel))
+      window = GTK_WINDOW (toplevel);
+  }
+
+  if (!window)
+    window = gtk_application_get_active_window (GTK_APPLICATION (shell));
+
+  ephy_download_new_for_download (download, window);
 }
 #endif
 
