@@ -32,7 +32,7 @@
 #include <gtk/gtk.h>
 
 static void
-test_embed_single_new ()
+test_embed_single_new (void)
 {
   EphyEmbedSingle *single;
 
@@ -43,8 +43,9 @@ test_embed_single_new ()
 }
 
 static void
-test_embed_single_get_from_shell ()
+test_embed_single_get_from_shell (void)
 {
+  EphyEmbedShell *embed_shell = ephy_embed_shell_get_default ();
   EphyEmbedSingle *single;
 
   single = EPHY_EMBED_SINGLE (ephy_embed_shell_get_embed_single (embed_shell));
@@ -52,7 +53,7 @@ test_embed_single_get_from_shell ()
 }
 
 static void
-test_embed_single_form_auth ()
+test_embed_single_form_auth (void)
 {
   EphyEmbedSingle *single;
   GSList *results = NULL;
@@ -103,7 +104,7 @@ main (int argc, char *argv[])
 
   ret = g_test_run ();
 
-  g_object_unref (ephy_shell);
+  g_object_unref (ephy_shell_get_default ());
   ephy_file_helpers_shutdown ();
 
   return ret;
